import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ModelConfig extends cdktf.TerraformMetaArguments {
    /**
    * Asset ID of model in project. Used when promoting model in project to deployment space.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#asset_id Model#asset_id}
    */
    readonly assetId?: string;
    /**
    * Checksum of Python object.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#checksum Model#checksum}
    */
    readonly checksum?: string;
    /**
    * Training input schema of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#input_schema Model#input_schema}
    */
    readonly inputSchema?: ModelInputSchema[] | cdktf.IResolvable;
    /**
    * Label column of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#label_column Model#label_column}
    */
    readonly labelColumn?: string;
    /**
    * tar.gz file of model from joblib.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#model_path Model#model_path}
    */
    readonly modelPath: string;
    /**
    * Name of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#name Model#name}
    */
    readonly name: string;
    /**
    * Project ID of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#project_id Model#project_id}
    */
    readonly projectId?: string;
    /**
    * Software spec of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#software_spec Model#software_spec}
    */
    readonly softwareSpec: string;
    /**
    * Space ID of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#space_id Model#space_id}
    */
    readonly spaceId?: string;
    /**
    * Type of model.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#type Model#type}
    */
    readonly type: string;
}
export interface ModelInputSchema {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#name Model#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/ibmcpd/r/model#type Model#type}
    */
    readonly type?: string;
}
export declare function modelInputSchemaToTerraform(struct?: ModelInputSchema | cdktf.IResolvable): any;
export declare class ModelInputSchemaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ModelInputSchema | cdktf.IResolvable | undefined;
    set internalValue(value: ModelInputSchema | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class ModelInputSchemaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ModelInputSchema[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ModelInputSchemaOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/ibmcpd/r/model ibmcpd_model}
*/
export declare class Model extends cdktf.TerraformResource {
    static readonly tfResourceType = "ibmcpd_model";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/ibmcpd/r/model ibmcpd_model} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ModelConfig
    */
    constructor(scope: Construct, id: string, config: ModelConfig);
    private _assetId?;
    get assetId(): string;
    set assetId(value: string);
    resetAssetId(): void;
    get assetIdInput(): string | undefined;
    private _checksum?;
    get checksum(): string;
    set checksum(value: string);
    resetChecksum(): void;
    get checksumInput(): string | undefined;
    get id(): string;
    private _inputSchema;
    get inputSchema(): ModelInputSchemaList;
    putInputSchema(value: ModelInputSchema[] | cdktf.IResolvable): void;
    resetInputSchema(): void;
    get inputSchemaInput(): cdktf.IResolvable | ModelInputSchema[] | undefined;
    private _labelColumn?;
    get labelColumn(): string;
    set labelColumn(value: string);
    resetLabelColumn(): void;
    get labelColumnInput(): string | undefined;
    private _modelPath?;
    get modelPath(): string;
    set modelPath(value: string);
    get modelPathInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _softwareSpec?;
    get softwareSpec(): string;
    set softwareSpec(value: string);
    get softwareSpecInput(): string | undefined;
    private _spaceId?;
    get spaceId(): string;
    set spaceId(value: string);
    resetSpaceId(): void;
    get spaceIdInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
